@@ -33,6 +33,7 @@
 #include "exceptions.hpp"
 #include "panel.hpp"
 #include "vcfReader.hpp"
+#include "chooseK.hpp"
 
 
 #ifndef PARAM
@@ -60,6 +61,8 @@ class DEploidIO{
     DEploidIO(int argc, char *argv[]);
     ~DEploidIO ();
 
+    ChooseK chooseK;
+
     void printHelp(std::ostream& out);
     bool help() const { return help_; }
     void printVersion(std::ostream& out);
@@ -68,17 +71,25 @@ class DEploidIO{
     void chromPainting ();
     bool doLsPainting() const { return this->doLsPainting_; }
     bool doIbdPainting() const { return this->doIbdPainting_; }
+    bool doIbdViterbiPainting() const { return this->doIbdViterbiPainting_;}
     bool doComputeLLK() const { return this->doComputeLLK_; }
     void computeLLKfromInitialHap();
+
+    // choose which version of deploid to use
     bool useIBD() const { return this->useIBD_;}
     bool useIbdOnly() const { return this->useIbdOnly_;}
     bool useLasso() const { return this->useLasso_;}
+    bool useBestPractice() const { return this->useBestPractice_;}
+
     void paintIBD();
+    void paintIBDviterbi();
     double ibdLLK_;
     void getIBDprobsIntegrated(vector < vector <double> > &prob);
     // Lasso related
     void dEploidLasso();
+    void dEploidLassoTrimfirst();
     vector <double> finalProp;
+    void dEploidLassoFullPanel();
 
     // Log
     void wrapUp();
@@ -103,7 +114,9 @@ class DEploidIO{
     vector < vector <double> > lassoRefCount;
     vector < vector <double> > lassoAltCount;
 
-    void writeHap (vector < vector <double> > &hap, bool useIBD = false);
+    void writeHap (vector < vector <double> > &hap, string jobbrief);
+    void writeVcf (vector < vector <double> > &hap,
+        vector <double> &prop, string jobbrief);
     bool doPrintLassoPanel_;
 
     // Trimming related
@@ -117,6 +130,12 @@ class DEploidIO{
     void setDoUpdateProp ( const bool setTo ) { this->doUpdateProp_ = setTo; }
     void setInitialPropWasGiven(const bool setTo) {this->initialPropWasGiven_ = setTo; }
 
+    void setKstrain ( const size_t setTo ) { this->kStrain_ = setTo;}
+    bool usePanel() const { return usePanel_; }
+    vector <string> chrom_;
+    size_t kStrain() const { return this->kStrain_;}
+    size_t lassoMaxNumPanel_;
+
   private:
     void core();
     double llkFromInitialHap_;
@@ -156,11 +175,14 @@ class DEploidIO{
     bool doAllowInbreeding_;
     bool doLsPainting_;
     bool doIbdPainting_;
+    bool doIbdViterbiPainting_;
+
     bool useIBD_;
     bool useIbdOnly_;
     bool useLasso_;
+    bool useBestPractice_;
 
-    vector <string> chrom_;
+    double vqslod_;
     vector <double> obsWsaf_;
     vector <size_t> wsafGt0At_;
     size_t nLoci_;
@@ -229,10 +251,10 @@ class DEploidIO{
     string dEploidGitVersion_;
     string lassoGitVersion_;
     string compileTime_;
-    string strExportLLK;
-    string strExportHap;
+    //string strExportLLK;
+    //string strExportHap;
     string strExportVcf;
-    string strExportProp;
+    //string strExportProp;
     string strExportLog;
     string strExportRecombProb;
 
@@ -240,6 +262,7 @@ class DEploidIO{
     string strIbdExportLLK;
     string strIbdExportHap;
     string strIbdExportProbs;
+    string strIbdExportViterbi;
 
     string strExportSingleFwdProbPrefix;
     string strExportPairFwdProb;
@@ -318,32 +341,42 @@ class DEploidIO{
 
     void setDoLsPainting ( const bool setTo ) { this->doLsPainting_ = setTo; }
     void setDoIbdPainting ( const bool setTo ) { this->doIbdPainting_ = setTo; }
+    void setDoIbdViterbiPainting ( const bool setTo ) { this->doIbdViterbiPainting_ = setTo; }
+
     void setUseIBD( const bool setTo) { this->useIBD_ = setTo; }
     void setUseIbdOnly(const bool setTo) { this->useIbdOnly_ = setTo;}
     void setUseLasso( const bool setTo) { this->useLasso_ = setTo; }
+    void setUseBestPractice ( const bool setTo) {this->useBestPractice_ = setTo;}
 
     bool initialPropWasGiven() const { return initialPropWasGiven_; }
 
     bool pleaseCheckInitialP() const { return pleaseCheckInitialP_; }
     void setPleaseCheckInitialP(const bool setTo) {this->pleaseCheckInitialP_ = setTo; }
 
+    size_t lassoMaxNumPanel() const { return this->lassoMaxNumPanel_; }
+    void setLassoMaxNumPanel(const size_t setTo) {this->lassoMaxNumPanel_ = setTo; }
+
     bool initialHapWasGiven() const { return initialHapWasGiven_; }
 
     bool randomSeedWasGiven() const {return this->randomSeedWasGiven_; }
 
+    void setVqslod ( const double setTo ) { this->vqslod_ = setTo; }
+    double vqslod() const { return this->vqslod_; }
+
     // log and export resutls
     void writeRecombProb ( Panel * panel );
     void writeIBDpostProb(vector < vector <double> > & reshapedProbs, vector <string> header);
+    void writeIBDviterbi(vector <size_t> & viterbiState);
     vector <string> ibdProbsHeader;
     vector <double> ibdProbsIntegrated;
 
-    void writeLLK (McmcSample * mcmcSample, bool useIBD = false);
-    void writeProp (McmcSample * mcmcSample, bool useIBD = false);
-    void writeVcf (McmcSample * mcmcSample);
+    void writeLLK (McmcSample * mcmcSample, string jobbrief);
+    void writeProp (McmcSample * mcmcSample, string jobbrief);
     void writeLastSingleFwdProb( vector < vector <double> >& probabilities, size_t chromIndex, size_t strainIndex, bool useIBD );
     void writeLastPairFwdProb( UpdatePairHap & updatePair, size_t chromIndex );
     void writeLog (ostream * writeTo );
     void writeEventCount();
+    void writeChooseKProportion();
 
     vector <double> IBDpathChangeAt;
     vector <double> finalIBDpathChangeAt;
@@ -363,11 +396,10 @@ class DEploidIO{
     vector <double> finalSiteOfOneMissCopyOne;
 
 
-    void writeMcmcRelated (McmcSample * mcmcSample, bool useIBD = false);
+    void writeMcmcRelated (McmcSample * mcmcSample, string jobbrief, bool useIBD = false);
     void readPanel();
 
     // Panel related
-    bool usePanel() const { return usePanel_; }
     string panelFileName_;
     double parameterG_;
     void setParameterG ( const double setTo ) { this->parameterG_ = setTo; }
@@ -381,8 +413,6 @@ class DEploidIO{
 
     void setNLoci ( const size_t setTo ) { this->nLoci_ = setTo;}
     size_t nLoci() const { return this->nLoci_; }
-    void setKstrain ( const size_t setTo ) { this->kStrain_ = setTo;}
-    size_t kStrain() const { return this->kStrain_;}
     void setKStrainWasManuallySet ( const size_t setTo ) { this->kStrainWasManuallySet_ = setTo; }
     bool kStrainWasSetByHap() const { return this->kStrainWasSetByHap_; }
     void setKStrainWasSetByHap ( const size_t setTo ) { this->kStrainWasSetByHap_ = setTo; }
@@ -417,7 +447,10 @@ class DEploidIO{
     vector < vector <double> > lassoSubsetPanel(size_t segmentStartIndex, size_t nLoci);
     void writePanel(Panel *panel, size_t chromi, vector <string> hdr);
 
-
+    void trimVec(vector <double> &vec, vector <size_t> &idx);
+    void trimming(vector <size_t> & trimmingCriteria);
+    void trimmingHalf(vector <size_t> & trimmingCriteria);
+    void computeObsWsaf();
 };
 
 #endif
