@@ -31,7 +31,7 @@ using std::endl;
 Panel::Panel():TxtReader() {
     this->setTruePanelSize(0);
     this->setInbreedingPanelSize(0);
-};
+}
 
 
 Panel::Panel(vector < double > pRec,
@@ -40,7 +40,8 @@ Panel::Panel(vector < double > pRec,
              vector < double > pRecRec,
              vector < double > pRecNoRec,
              vector < double > pNoRecNoRec,
-             vector < vector < double > > content) {
+             vector < vector < double > > content,
+             vector < string > header) {
              this->pRec_ = vector <double> (pRec.begin(), pRec.end());
     this->pRecEachHap_ = vector <double> (pRecEachHap.begin(),
                                           pRecEachHap.end());
@@ -56,17 +57,60 @@ Panel::Panel(vector < double > pRec,
         this->content_.push_back(vector <double> (content[i].begin(),
                                                   content[i].end()));
     }
+    this->header_ = vector <string> (header.begin(), header.end());
     this->setTruePanelSize(this->content_[0].size());
     assert(this->pRec_.size() == this->pRecEachHap_.size());
     assert(this->pRec_.size() == this->content_.size());
 }
 
 
+Panel::Panel(const Panel &copyFrom){
+    nLoci_ = copyFrom.nLoci_;
+
+    chrom_ = vector <string> (copyFrom.chrom_.begin(), copyFrom.chrom_.end());
+
+    indexOfChromStarts_ = vector < size_t > (
+        copyFrom.indexOfChromStarts_.begin(),
+        copyFrom.indexOfChromStarts_.end());
+
+    position_ = vector < vector < int> > (copyFrom.position_.begin(),
+                                          copyFrom.position_.end());
+
+    this->pRec_ = vector<double>(copyFrom.pRec_.begin(),
+                                 copyFrom.pRec_.end());
+    this->pRecEachHap_ = vector <double> (copyFrom.pRecEachHap_.begin(),
+                                          copyFrom.pRecEachHap_.end());
+    this->pNoRec_ = vector <double> (copyFrom.pNoRec_.begin(),
+                                     copyFrom.pNoRec_.end());
+    this->pRecRec_ = vector <double> (copyFrom.pRecRec_.begin(),
+                                      copyFrom.pRecRec_.end());
+    this->pRecNoRec_ = vector <double> (copyFrom.pRecNoRec_.begin(),
+                                        copyFrom.pRecNoRec_.end());
+    this->pNoRecNoRec_ = vector <double> (copyFrom.pNoRecNoRec_.begin(),
+                                          copyFrom.pNoRecNoRec_.end());
+    for (size_t i = 0; i < copyFrom.content_.size(); i++) {
+        this->content_.push_back(vector <double> (copyFrom.content_[i].begin(),
+                                                  copyFrom.content_[i].end()));
+    }
+    this->setTruePanelSize(this->content_[0].size());
+
+    truePanelSize_ = copyFrom.truePanelSize_;
+
+    inbreedingPanelSize_ = copyFrom.inbreedingPanelSize_;
+
+    this->fileName_ = copyFrom.fileName_;
+    for (size_t i = 0; i < copyFrom.header_.size(); i++){
+        header_.push_back(copyFrom.header_[i]);
+    }
+}
+
+
+
 void Panel::readFromFile( const char inchar[] ) {
     this->readFromFileBase( inchar );
     this->setTruePanelSize( this->nInfoLines_ );
     this->setInbreedingPanelSize( this->truePanelSize() );
-};
+}
 
 
 void Panel::checkForExceptions( size_t nLoci, string panelFileName ) {
@@ -82,6 +126,13 @@ void Panel::checkForExceptions( size_t nLoci, string panelFileName ) {
 
 
 void Panel::computeRecombProbs( double averageCentimorganDistance, double G, bool useConstRecomb, double constRecombProb, bool forbidCopyFromSame ) {
+    pRec_.clear();
+    pRecEachHap_.clear();
+    pNoRec_.clear();
+    pRecRec_.clear();
+    pRecNoRec_.clear();
+    pNoRecNoRec_.clear();
+
     assert(pRec_.size() == 0 );
     assert(pRecEachHap_.size() == 0 );
     assert(pNoRec_.size() == 0 );
@@ -214,6 +265,50 @@ void Panel::updatePanelWithHaps(size_t inbreedingPanelSizeSetTo, size_t excluded
 }
 
 
+void Panel::trimVec(vector <double> &vec, const vector <size_t> &idx) {
+    vector <double> ret;
+    for (auto const& value : idx){
+        ret.push_back(vec[value]);
+    }
+    //return ret;
+    vec.clear();
+    for (auto const& value : ret){
+        vec.push_back(value);
+    }
+}
+
+
+void Panel::findAndKeepMarkersGivenIndex(
+        const vector <size_t> & givenIndex) {
+    this->setDoneGetIndexOfChromStarts(false);
+    dout << " findAndKeepMarkersGivenIndex called " << givenIndex.size() <<endl;
+    this->findWhoToBeKeptGivenIndex(givenIndex);
+    this->getIndexOfChromStarts();
+    this->removeMarkers();
+    this->trimVec(this->pRec_, givenIndex);
+    this->trimVec(this->pRecEachHap_, givenIndex);
+    this->trimVec(this->pNoRec_, givenIndex);
+    this->trimVec(this->pRecRec_, givenIndex);
+    this->trimVec(this->pRecNoRec_, givenIndex);
+    this->trimVec(this->pNoRecNoRec_, givenIndex);
+}
+
+
+void Panel::findAndKeepMarkersGivenIndexHalf(
+        const vector <size_t> & givenIndex) {
+    this->setDoneGetIndexOfChromStarts(false);
+    dout << " findAndKeepMarkersGivenIndex called " << givenIndex.size() <<endl;
+    this->findWhoToBeKeptGivenIndexHalf(givenIndex);
+    this->getIndexOfChromStartsHalf();
+    this->removeMarkers();
+    this->trimVec(this->pRec_, givenIndex);
+    this->trimVec(this->pRecEachHap_, givenIndex);
+    this->trimVec(this->pNoRec_, givenIndex);
+    this->trimVec(this->pRecRec_, givenIndex);
+    this->trimVec(this->pRecNoRec_, givenIndex);
+    this->trimVec(this->pNoRecNoRec_, givenIndex);
+}
+
 void IBDrecombProbs::computeRecombProbs( double averageCentimorganDistance, double G, bool useConstRecomb, double constRecombProb ) {
     assert(pRec_.size() == 0 );
     assert(pNoRec_.size() == 0 );
@@ -225,7 +320,7 @@ void IBDrecombProbs::computeRecombProbs( double averageCentimorganDistance, doub
             geneticDistance = (double)(this->position_[i][j] - this->position_[i][j-1])/averageMorganDistance ;
             //rho = geneticDistance * 2 * Ne;
             rho = geneticDistance * G;
-            double pRecTmp = ( useConstRecomb ) ? constRecombProb : 1.0 - exp(-rho);
+            double pRecTmp = ( useConstRecomb ) ? constRecombProb : (1.0 - exp(-rho));
             this->pRec_.push_back( pRecTmp );
             double pNoRecTmp = 1.0 - pRecTmp;
             this->pNoRec_.push_back( pNoRecTmp );
@@ -238,7 +333,6 @@ void IBDrecombProbs::computeRecombProbs( double averageCentimorganDistance, doub
 }
 
 
-
 //vector<vector<double>> outtrans(out[0].size(),
                                     //vector<double>(out.size()));
     //for (size_t i = 0; i < out.size(); ++i)
