@@ -69,7 +69,10 @@ class Panel: public TxtReader{
           vector < double > pRecRec,
           vector < double > pRecNoRec,
           vector < double > pNoRecNoRec,
-          vector < vector < double > > content);
+          vector < vector < double > > content,
+          vector < string > header);
+    Panel(const Panel &copyFrom);
+
     //Panel(const char inchar[] );
 
     // Methods
@@ -84,6 +87,11 @@ class Panel: public TxtReader{
     void buildExamplePanel1();
     void buildExamplePanel2();
 
+    void trimVec(vector <double> &vec, const vector <size_t> &idx);
+    //void findWhoToBeKeptGivenIndex(const vector <size_t> & givenIndex);
+    void findAndKeepMarkersGivenIndex(const vector <size_t> & givenIndex);
+    void findAndKeepMarkersGivenIndexHalf(const vector <size_t> & givenIndex);
+
   public:
     virtual ~Panel() {};
 };
